/*
 *      dnsutl - utilities to make DNS easier to configure
 *      Copyright (C) 2006, 2007 Peter Miller
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program. If not, see
 *      <http://www.gnu.org/licenses/>.
 */

%{

#include <conf.h>
#include <grammar.h>
#include <lex.h>

%}

%token LBRACE
%token RBRACE
%token SEMICOLON
%token STRING
%token WORD

%{

static conf_t *root;

conf_t *
grammar(const char *filename)
{
    extern int yyparse(void);

    lex_open(filename);
    yyparse();
    lex_close();
    return root;
}

%}

%union
{
    string_ty *lv_string;
    struct conf_t *lv_conf;
}

%type <lv_conf> semi
%type <lv_conf> semi_list
%type <lv_conf> word
%type <lv_conf> word_list
%type <lv_string> STRING
%type <lv_string> WORD

%%

cfg
    : semi_list
        { root = $1; }
    ;

semi_list
    : semi
        {
            $$ = conf_list_new();
            conf_list_append($$, $1);
        }
    | semi_list semi
        {
            $$ = $1;
            conf_list_append($$, $2);
        }
    ;

semi
    : word_list SEMICOLON
        { $$ = $1; }
    ;

word_list
    : /* empty */
        { $$ = conf_list_new(); }
    | word_list word
        {
            $$ = $1;
            conf_list_append($$, $2);
        }
    ;

word
    : WORD
        { $$ = conf_string_new($1); }
    | STRING
        { $$ = conf_string_new($1); }
    | LBRACE semi_list RBRACE
        { $$ = $2; }
    ;
