#!/bin/sh
#
#       dnsutl - utilities to make DNS easier to configure
#       Copyright (C) 2006, 2007 Peter Miller
#
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 3 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program. If not, see
#       <http://www.gnu.org/licenses/>.
#
work=/tmp/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 1; fi
MANPATH=${here}:${MANPATH-.}
export MANPATH

if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi

fail()
{
        set +x
        echo 'FAILED test of the SRRF functionality' 1>&2
        cd $here
        rm -rf $work
        exit 1
}
pass()
{
        set +x
        cd $here
        rm -rf $work
        exit 0
}
trap \"fail\" 1 2 3 15

mkdir $work
if test $? -ne 0 ; then exit 1; fi
cd $work
if test $? -ne 0 ; then fail; fi

#
# test the SRRF functionality
#
cat > test.in << 'fubar'
$ORIGIN .
$TTL 86400     ; 1 day
1.16.172.in-addr.arpa   IN SOA  miller.emu.id.au. hostmaster.miller.emu.id.au. (
    50619553   ; serial
    10800      ; refresh (3 hours)
    1800       ; retry (30 minutes)
    604800     ; expire (1 week)
    86400      ; minimum (1 day)
)
ns      ns.miller.emu.id.au.
$ORIGIN 1.16.172.in-addr.arpa.
1 PTR     baza.miller.emu.id.au.
fubar
if test $? -ne 0 ; then fail; fi

$bin/dns-filter test.in > test.out
if test $? -ne 0 ; then fail; fi

cat > test.ok << 'fubar'
$origin 1.16.172.in-addr.arpa.
$config maximum_name_length 15
$config warning_name_length 0
$config allow_upper_case 0
$line 3 "test.in"
@       86400   in      soa     miller.emu.id.au. hostmaster.miller.emu.id.au. (
                                50619553 ; serial
                                10800 ; refresh: 3 hours
                                1800 ; retry: 30 minutes
                                604800 ; expire: 1 week
                                86400 ) ; minimum: 1 day

        86400   in      ns      ns.miller.emu.id.au.

1       86400   in      ptr     baza.miller.emu.id.au.
fubar
if test $? -ne 0 ; then fail; fi

diff test.ok test.out
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass
